@@ -14,7 +14,12 @@ class Setup:
         else: print("* You don't have permission to run this. \n * This may been because you edited the files in the OS folder \nReset your OS by running the make() function.")
     
     def PrintStartupMessage(self, message):
+        import time
+        import os
+
         if self.private.authent == "authenticated":
             print(message)
             print("* Powered by PyOS")
+            time.sleep(2)
+            os.system('clear')
         else: print("* You don't have permission to run this. \n * This may been because you edited the files in the OS folder \nReset your OS by running the make() function.")
